parse_table_constraint_query_results

Function parse_table_constraint_query_results 

pub fn parse_table_constraint_query_results(
    results: Vec<TableConstraintsQueryResult>,
) -> Vec<Constraint>
Assumed to be ordered by table name, then constraint name, then ordinal position, then the constraint name of the foreign key, then the ordinal position of the foreign key